@@ -5,4 +5,4 @@ from ..models.department import Department
 
 @admin.register(Department)
 class DepartmentAdmin(admin.ModelAdmin):
-    list_display = ('name', 'code')
+    list_display = ("name", "code")
