@@ -5,4 +5,4 @@ from ..models.school import School
 
 @admin.register(School)
 class SchoolAdmin(admin.ModelAdmin):
-    list_display = ('name', 'address')
+    list_display = ("name", "address")
