@@ -5,9 +5,11 @@ from django.contrib.admin.utils import unquote
 from django.contrib.auth import get_user_model
 from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.exceptions import ValidationError
-from django.db.models import BooleanField, Func
+from django.db.models import BooleanField, F, Func
 from django.db.models.expressions import Random
+from django.db.models.functions import Coalesce
 from django.http import HttpResponseRedirect
+from django.template.response import SimpleTemplateResponse
 from django.urls import reverse
 from django.utils.formats import date_format
 from django.utils.html import format_html
@@ -22,7 +24,6 @@ from ..forms.subjects import (
     SubjectAdminForm,
 )
 from ..models.subjects import (
-    CHAT_GROUP_TYPE_LABELS,
     DEFAULT_TEXTS,
     Subject,
     SubjectAttachment,
@@ -39,7 +40,7 @@ from ..models.subjects import (
     SubjectTypeAttachment,
     SubjectVariant,
 )
-from ..models.utils import lazy_help_text_with_default, lazy_help_text_with_html_default
+from ..models.utils import lazy_help_text_with_html_default
 from ..utils import amount_color, currency
 from .bulkupdate import BulkUpdateMixin
 from .export import AdminExportMixin
@@ -239,10 +240,6 @@ class SubjectBaseAdmin(AdminExportMixin, BulkUpdateMixin, SendMessageAdminMixin,
                     form.base_fields[field_name].help_text,
                     getattr(request.subject_type, field_name) or DEFAULT_TEXTS[field_name],
                 )
-            form.base_fields["chat_group_type"].help_text = lazy_help_text_with_default(
-                form.base_fields["chat_group_type"].help_text,
-                CHAT_GROUP_TYPE_LABELS[request.subject_type.chat_group_type],
-            )
 
         return form
 
@@ -458,6 +455,7 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
         "request_payment",
         "offer_refund",
         "generate_refund_request",
+        "export_invoices_xml",
         "cancel",
         "cancel_cancelation_request",
     )
@@ -567,6 +565,7 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
         "subject__department",
         ("subject__subject_type", SubjectTypeListFilter),
         "subject__registration_type",
+        "subject__organization",
         ApprovedListFilter,
         CanceledListFilter,
         "registration_link",
@@ -643,7 +642,13 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
                 "subject",
                 "user",
             )
-            .annotate(random_number=Random())
+            .annotate(
+                random_number=Random(),
+                subject__organization__id=Coalesce(
+                    F("subject__organization_id"),
+                    F("subject__subject_type__organization_id"),
+                ),
+            )
         )
 
     def approve(self, request, queryset):
@@ -695,6 +700,13 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
 
     generate_refund_request.short_description = _("Generate refund requests for selected registrations")
 
+    def export_invoices_xml(self, request, queryset):
+        response = SimpleTemplateResponse("leprikon/invoices.xml", {"registrations": queryset}, content_type="text/xml")
+        response["Content-Disposition"] = 'attachment; filename="invoices.xml"'
+        return response
+
+    export_invoices_xml.short_description = _("Export selected registrations as invoices in XML")
+
     def cancel(self, request, queryset):
         for registration in queryset.all():
             try:
