@@ -12,6 +12,8 @@ from tempfile import NamedTemporaryFile
 import qrcode
 from bankreader.models import Transaction as BankreaderTransaction
 from cms.models.fields import PageField
+from cms.models.pagemodel import Page
+from cms.signals.apphook import set_restart_trigger
 from django.core.exceptions import ValidationError
 from django.db import models, transaction
 from django.dispatch import receiver
@@ -35,7 +37,7 @@ from .agegroup import AgeGroup
 from .agreements import Agreement, AgreementOption
 from .citizenship import Citizenship
 from .department import Department
-from .fields import BirthNumberField, ColorField, EmailField, PostalCodeField, PriceField
+from .fields import BirthNumberField, ColorField, EmailField, PostalCodeField, PriceField, UniquePageField
 from .leprikonsite import LeprikonSite
 from .organizations import Organization
 from .pdfmail import PdfExportAndMailMixin
@@ -84,20 +86,6 @@ DEFAULT_TEXTS = {
     ),
 }
 
-CHAT_GROUP_BROADCAST = "B"
-CHAT_GROUP_CHAT = "C"
-CHAT_GROUP_TYPE_LABELS = OrderedDict(
-    [
-        (CHAT_GROUP_BROADCAST, _("broadcast group")),
-        (CHAT_GROUP_CHAT, _("chat group")),
-    ]
-)
-
-CHAT_GROUP_TYPE_HELP_TEXT = _(
-    "Only the leader can write to broadcast group. Users may reply to the sender with direct messages.\n"
-    "Chat group allows all members to chat with each other."
-)
-
 
 class SubjectType(models.Model):
     COURSE = "course"
@@ -122,7 +110,19 @@ class SubjectType(models.Model):
     name_genitiv = models.CharField(_("name (genitiv)"), max_length=150, blank=True)
     name_akuzativ = models.CharField(_("name (akuzativ)"), max_length=150, blank=True)
     plural = models.CharField(_("name (plural)"), max_length=150)
-    slug = models.SlugField()
+    slug = models.SlugField(unique=True)
+    page = UniquePageField(
+        blank=True,
+        null=True,
+        on_delete=models.SET_NULL,
+        related_name="leprikon_subject_type",
+        verbose_name=_("page"),
+        help_text=_(
+            "Select page, where the subjects will be listed. New subject type requireds new page. "
+            "If You assign an existing page, the current content of the page will be replaced "
+            "with the new subject list."
+        ),
+    )
     order = models.IntegerField(_("order"), blank=True, default=0)
     questions = models.ManyToManyField(
         Question,
@@ -165,13 +165,6 @@ class SubjectType(models.Model):
     organization = models.ForeignKey(
         Organization, blank=True, null=True, on_delete=models.SET_NULL, related_name="+", verbose_name=_("organization")
     )
-    chat_group_type = models.CharField(
-        _("default chat group type"),
-        max_length=1,
-        choices=CHAT_GROUP_TYPE_LABELS.items(),
-        default=CHAT_GROUP_BROADCAST,
-        help_text=CHAT_GROUP_TYPE_HELP_TEXT,
-    )
     text_registration_received = HTMLField(
         _("text: registration received"),
         blank=True,
@@ -471,14 +464,6 @@ class Subject(TimesMixin, models.Model):
         verbose_name=_("organization"),
         help_text=_("Only use to set value specific for this subject."),
     )
-    chat_group_type = models.CharField(
-        _("chat group type"),
-        blank=True,
-        max_length=1,
-        null=True,
-        choices=CHAT_GROUP_TYPE_LABELS.items(),
-        help_text=CHAT_GROUP_TYPE_HELP_TEXT,
-    )
     text_registration_received = HTMLField(_("text: registration received"), blank=True, default="")
     text_registration_approved = HTMLField(_("text: registration approved"), blank=True, default="")
     text_registration_refused = HTMLField(_("text: registration refused"), blank=True, default="")
@@ -594,6 +579,10 @@ class Subject(TimesMixin, models.Model):
     def full(self):
         return self.max_registrations_count and self.active_registrations_count >= self.max_registrations_count
 
+    @property
+    def over_capapcity(self):
+        return self.max_registrations_count and self.active_registrations_count > self.max_registrations_count
+
     def get_absolute_url(self):
         return reverse(self.subject_type.slug + ":subject_detail", args=(self.id,))
 
@@ -1661,6 +1650,55 @@ def payment_create_subject_payment(instance, **kwargs):
     )
 
 
+@receiver(models.signals.post_save, sender=SubjectType)
+def subject_type_update_page(instance, **kwargs):
+    subject_type = instance
+    if subject_type.page_id:
+        updated = Page.objects.filter(
+            application_urls="LeprikonSubjectTypeApp",
+            application_namespace=subject_type.slug,
+        ).exclude(models.Q(id=subject_type.page_id) | models.Q(publisher_draft=subject_type.page_id)).update(
+            application_urls=None,
+            application_namespace=None,
+        ) + Page.objects.filter(
+            models.Q(id=subject_type.page_id) | models.Q(publisher_draft=subject_type.page_id)
+        ).update(
+            application_urls="LeprikonSubjectTypeApp",
+            application_namespace=subject_type.slug,
+        )
+    else:
+        updated = Page.objects.filter(
+            application_urls="LeprikonSubjectTypeApp",
+            application_namespace=subject_type.slug,
+        ).update(
+            application_urls=None,
+            application_namespace=None,
+        )
+    if updated:
+        set_restart_trigger()
+
+
+@receiver(models.signals.post_save, sender=Page)
+def page_update_subject_type(instance, **kwargs):
+    page = instance
+    if not page.publisher_is_draft:
+        return
+    if page.application_urls != "LeprikonSubjectTypeApp":
+        SubjectType.objects.filter(page=page).update(page=None)
+        return
+    subject_type = SubjectType.objects.filter(slug=page.application_namespace).first()
+    if subject_type is None:
+        Page.objects.filter(id=page.id).update(
+            application_urls=None,
+            application_namespace=None,
+        )
+        set_restart_trigger()
+        return
+    SubjectType.objects.filter(page=page).exclude(id=subject_type.id).update(page=None)
+    if subject_type.page_id != page.id:
+        SubjectType.objects.filter(id=subject_type.id).update(page=page)
+
+
 @receiver(models.signals.post_save, sender=BankreaderTransaction)
 def transaction_create_subject_payment(instance, **kwargs):
     transaction = instance
