@@ -35,8 +35,8 @@ class ReportEventPaymentsView(FormView):
             accounted__gte=context["date_start"],
             accounted__lte=context["date_end"],
         )
-        context["received_payments_sum"] = context["received_payments"].aggregate(sum=Sum("amount"))["sum"]
-        context["returned_payments_sum"] = context["returned_payments"].aggregate(sum=Sum("amount"))["sum"]
+        context["received_payments_sum"] = context["received_payments"].aggregate(sum=Sum("amount"))["sum"] or 0
+        context["returned_payments_sum"] = context["returned_payments"].aggregate(sum=Sum("amount"))["sum"] or 0
         context["sum"] = context["received_payments_sum"] - context["returned_payments_sum"]
         return TemplateResponse(self.request, self.template_name, self.get_context_data(**context))
 
@@ -108,6 +108,7 @@ class ReportEventStatsView(FormView):
     def form_valid(self, form):
         d = form.cleaned_data["date"]
         paid_only = form.cleaned_data["paid_only"]
+        unique_participants = form.cleaned_data["unique_participants"]
         context = form.cleaned_data
         context["form"] = form
 
@@ -127,8 +128,15 @@ class ReportEventStatsView(FormView):
             ]
         else:
             participants = list(participants)
+
         context["events_count"] = len(set(participant.registration.subject_id for participant in participants))
 
+        if unique_participants:
+            participants_by_name_and_birth_date = {
+                (p.first_name.lower(), p.last_name.lower(), p.birth_date): p for p in participants
+            }
+            participants = list(participants_by_name_and_birth_date.values())
+
         citizenships = list(Citizenship.objects.all())
         context["citizenships"] = citizenships
 
